module :py:mod:`tarantool`
==========================

.. automodule:: tarantool
   :exclude-members: Connection, MeshConnection,
      Error, DatabaseError, NetworkError, NetworkWarning,
      SchemaError

   .. autoclass:: tarantool.Connection
      :exclude-members: Error, DatabaseError, InterfaceError,
         ConfigurationError, SchemaError, NetworkError,
         Warning, DataError, OperationalError, IntegrityError,
         InternalError, ProgrammingError, NotSupportedError

      .. autoattribute:: Error
         :noindex:

      .. autoattribute:: DatabaseError
         :noindex:

      .. autoattribute:: InterfaceError
         :noindex:

      .. autoattribute:: ConfigurationError
         :noindex:

      .. autoattribute:: SchemaError
         :noindex:

      .. autoattribute:: NetworkError
         :noindex:

      .. autoattribute:: Warning
         :noindex:

      .. autoattribute:: DataError
         :noindex:

      .. autoattribute:: OperationalError
         :noindex:

      .. autoattribute:: IntegrityError
         :noindex:

      .. autoattribute:: InternalError
         :noindex:

      .. autoattribute:: ProgrammingError
         :noindex:

      .. autoattribute:: NotSupportedError
         :noindex:

   .. autoclass:: tarantool.MeshConnection
      :exclude-members: Error, DatabaseError, InterfaceError,
         ConfigurationError, SchemaError, NetworkError,
         Warning, DataError, OperationalError, IntegrityError,
         InternalError, ProgrammingError, NotSupportedError

      .. autoattribute:: Error
         :noindex:

      .. autoattribute:: DatabaseError
         :noindex:

      .. autoattribute:: InterfaceError
         :noindex:

      .. autoattribute:: ConfigurationError
         :noindex:

      .. autoattribute:: SchemaError
         :noindex:

      .. autoattribute:: NetworkError
         :noindex:

      .. autoattribute:: Warning
         :noindex:

      .. autoattribute:: DataError
         :noindex:

      .. autoattribute:: OperationalError
         :noindex:

      .. autoattribute:: IntegrityError
         :noindex:

      .. autoattribute:: InternalError
         :noindex:

      .. autoattribute:: ProgrammingError
         :noindex:

      .. autoattribute:: NotSupportedError
         :noindex:

   .. autoexception:: Error
      :noindex:

   .. autoexception:: DatabaseError
      :noindex:

   .. autoexception:: DatabaseError
      :noindex:

   .. autoexception:: NetworkError
      :noindex:

   .. autoexception:: NetworkWarning
      :noindex:

   .. autoexception:: SchemaError
      :noindex:
